@@ -13,13 +13,14 @@ from .installation import (
 )
 from .system import exec_shell
 from .errors import CloudCliError
+from . import check_version, to_str
 
 
 class AWSCli:
     def __init__(self, bin_path=None):
         # aws CLI supported versions interval
         self.min_version = (0, 0, 0)
-        self.max_version = (1, 19, 18)
+        self.max_version = (1, 19, 97)
         # Path to look up for executable
         self.bin_path = None
         # Force aws CLI binary path if bin_path exists and contains
@@ -61,25 +62,11 @@ class AWSCli:
 
         logging.info("aws CLI version: %s", '.'.join(map(str, version)))
 
-        # Verify if the version fetched is supported
-        for i in range(0, 3):
-            min = self.min_version[i]
-            max = self.max_version[i]
-
-            if version[i] < max:
-                # If current digit is below the maximum value, no need to
-                # check others digits, we are good
-                break
-
-            if version[i] not in list(range(min, max + 1)):
-                raise Exception(
-                    ("aws CLI version %s not supported, must be between %s and"
-                     " %s") % (
-                        '.'.join(map(str, version)),
-                        '.'.join(map(str, self.min_version)),
-                        '.'.join(map(str, self.max_version)),
-                    )
-                )
+        if not check_version(version, self.min_version, self.max_version):
+            raise Exception(
+                "aws CLI version %s not supported, must be between %s and %s"
+                % (to_str(version), to_str(self.min_version),
+                   to_str(self.max_version)))
 
     def bin(self, binary):
         """
@@ -252,7 +239,7 @@ class AzureCli:
     def __init__(self, bin_path=None):
         # azure CLI supported versions interval
         self.min_version = (0, 0, 0)
-        self.max_version = (2, 20, 0)
+        self.max_version = (2, 25, 0)
         # Path to look up for executable
         self.bin_path = None
         # Force azure CLI binary path if bin_path exists and contains
@@ -292,25 +279,11 @@ class AzureCli:
 
         logging.info("azure CLI version: %s", '.'.join(map(str, version)))
 
-        # Verify if the version fetched is supported
-        for i in range(0, 3):
-            min = self.min_version[i]
-            max = self.max_version[i]
-
-            if version[i] < max:
-                # If current digit is below the maximum value, no need to
-                # check others digits, we are good
-                break
-
-            if version[i] not in list(range(min, max + 1)):
-                raise Exception(
-                    ("azure CLI version %s not supported, must be between %s and"
-                     " %s") % (
-                        '.'.join(map(str, version)),
-                        '.'.join(map(str, self.min_version)),
-                        '.'.join(map(str, self.max_version)),
-                    )
-                )
+        if not check_version(version, self.min_version, self.max_version):
+            raise Exception(
+                "azure CLI version %s not supported, must be between %s and %s"
+                % (to_str(version), to_str(self.min_version),
+                   to_str(self.max_version)))
 
     def bin(self, binary):
         """
@@ -321,7 +294,6 @@ class AzureCli:
         else:
             return binary
 
-
     def check_instance_type_availability(self, instance_type, region):
         try:
             output = exec_shell([
@@ -452,6 +424,10 @@ class AzureCli:
         execute_install_script(script_name)
 
 
+class AzureDBCli(AzureCli):
+    pass
+
+
 class GCloudCli:
     def __init__(self, bin_path=None):
         # gcloud CLI supported versions interval
@@ -496,25 +472,11 @@ class GCloudCli:
 
         logging.info("gcloud CLI version: %s", '.'.join(map(str, version)))
 
-        # Verify if the version fetched is supported
-        for i in range(0, 3):
-            min = self.min_version[i]
-            max = self.max_version[i]
-
-            if version[i] < max:
-                # If current digit is below the maximum value, no need to
-                # check others digits, we are good
-                break
-
-            if version[i] not in list(range(min, max + 1)):
-                raise Exception(
-                    ("gcloud CLI version %s not supported, must be between %s and"
-                     " %s") % (
-                        '.'.join(map(str, version)),
-                        '.'.join(map(str, self.min_version)),
-                        '.'.join(map(str, self.max_version)),
-                    )
-                )
+        if not check_version(version, self.min_version, self.max_version):
+            raise Exception(
+                "gcloud CLI version %s not supported, must be between %s and %s"
+                % (to_str(version), to_str(self.min_version),
+                   to_str(self.max_version)))
 
     def bin(self, binary):
         """
@@ -667,22 +629,29 @@ class GCloudCli:
         execute_install_script(script_name)
 
 
+class GCloudSQLCli(GCloudCli):
+    pass
+
 class CloudCli:
 
     def __init__(self, cloud, bin_path):
         self.cloud = cloud
-        if self.cloud == 'aws':
+        if self.cloud in ['aws', 'aws-pot']:
             self.cli = AWSCli(bin_path)
         elif self.cloud == 'aws-rds':
             self.cli = AWSRDSCli(bin_path)
         elif self.cloud == 'aws-rds-aurora':
             self.cli = AWSRDSAuroraCli(bin_path)
-        elif self.cloud == 'azure':
+        elif self.cloud in ['azure', 'azure-pot']:
             self.cli = AzureCli(bin_path)
-        elif self.cloud == 'gcloud':
+        elif self.cloud == 'azure-db':
+            self.cli = AzureDBCli(bin_path)
+        elif self.cloud in ['gcloud', 'gcloud-pot']:
             self.cli = GCloudCli(bin_path)
+        elif self.cloud == 'gcloud-sql':
+            self.cli = GCloudSQLCli(bin_path)
         else:
-            raise Exception("Unknown cloud %s", self.cloud)
+            raise Exception("Unknown cloud %s" % self.cloud)
 
     def check_instance_type_availability(self, instance_type, region):
         return self.cli.check_instance_type_availability(instance_type, region)
