@@ -11,7 +11,7 @@ EC2Spec = {
                 'c5.large', 'c5.xlarge', 'c5.2xlarge', 'c5.4xlarge',
                 'c5.9xlarge', 'c5.12xlarge', 'c5.18xlarge', 'c5.24xlarge',
                 'c5.metal', 'r5n.xlarge', 'r5n.2xlarge', 'r5n.4xlarge',
-                'r5n.8xlarge'
+                'r5n.8xlarge', 'i3.metal', 'i3en.metal'
             ],
             default='c5.2xlarge'
         ),
@@ -192,7 +192,7 @@ EC2Spec = {
             choices=[
                 'c5.large', 'c5.xlarge', 'c5.2xlarge', 'c5.4xlarge',
                 'c5.9xlarge', 'c5.12xlarge', 'c5.18xlarge', 'c5.24xlarge',
-                'c5.metal'
+                'c5.metal', 'i3.metal', 'i3en.metal'
             ] + AWSGlobalInstanceChoices,
             default='c5.2xlarge'
         ),
